# -*- coding: utf-8 -*-
# Copyright 2020 The PsiZ Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Module of core `trials` functionality.

Functions:
    stack: Combine a list of multiple SimilarityTrial objects into one.

"""


def stack(trials_list):
    """Return an instance of a trials object of all trials.

    Args:
        trials_list: A tuple of trial objects to be stacked.
            All objects should be of the same class.

    Returns:
        A new trials object.

    """
    trials_stacked = trials_list[0].stack(trials_list)
    return trials_stacked
